@@ -5,14 +5,14 @@
 (defparameter *autoconf-prefix* "/usr/local")
 (defparameter *autoconf-exec_prefix* "/usr/local")
 (defparameter *autoconf-package* "maxima")
-(defparameter *autoconf-version* "5.27.0")
+(defparameter *autoconf-version* "5.29.1")
 (defparameter *autoconf-libdir* "/usr/local/lib")
 (defparameter *autoconf-libexecdir* "/usr/local/libexec")
 (defparameter *autoconf-datadir* "/usr/local/share")
 (defparameter *autoconf-infodir* "/usr/local/info")
-(defparameter *autoconf-host* "i386-unknown-openbsd5.2")
+(defparameter *autoconf-host* "powerpc-unknown-openbsd5.5")
 (defparameter *autoconf-win32* "false")
 (defparameter *autoconf-ld-flags* "")
  
-(defparameter *maxima-source-root* "/usr/obj/maxima-5.27.0/maxima-5.27.0")
+(defparameter *maxima-source-root* "/usr/obj/ports/maxima-5.29.1/maxima-5.29.1")
 (defparameter *maxima-default-layout-autotools* "true")
