@@ -23,6 +23,10 @@
 (defvar $gamma_expand nil
   "Expand gamma(z+n) for n an integer when T.") 
 
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+
+;;; Implementation of the plog function
+
 (defmfun simpplog (x vestigial z)
   (declare (ignore vestigial))
   (prog (varlist dd check y)
@@ -34,7 +38,10 @@
 	    (return (eqtest (list '(%plog) x) check))))
      (newvar x)
      (cond
-       ((and (eq '$%i (car varlist)) (not (some #'atom (cdr varlist))))
+       ((and (member '$%i varlist)
+	     (not (some #'(lambda (v)
+			    (and (atom v) (not (eq v '$%i))))
+			varlist)))
 	(setq dd (trisplit x))
 	(cond ((setq z (patan (car dd) (cdr dd)))
 	       (return (add2* (simpln (list '(%log) 
@@ -108,6 +115,14 @@
 		     ((alike1 r '((mexpt) 3 ((rat) -1 2)))
 		      (archk a b (list '(mtimes) '((rat) 1 6) '$%pi))))))))
 
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+
+;;; Implementation of the Binomial coefficient
+
+;; Verb function for the Binomial coefficient
+(defun $binomial (x y)
+  (simplify (list '(%binomial) x y)))
+
 ;; Binomial has Mirror symmetry
 (defprop %binomial t commutes-with-conjugate)
 
@@ -165,11 +180,15 @@
      (setq u (addk -1 u) v (1- v))
      (go loop)))
 
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+
+;;; Implementation of the Beta function
+
 (declare-top (special $numer $gammalim))
 
 (defmvar $beta_args_sum_to_integer nil)
 
-;;; The Beta funtion has mirror symmetry
+;;; The Beta function has mirror symmetry
 (defprop $beta t commutes-with-conjugate)
 
 (defmfun simpbeta (x vestigial z &aux check)
@@ -336,6 +355,10 @@
            (power (simplify (list '($pochhammer) (add u n) (- n))) -1)
            (simplify (list '($beta) u v)))))
 
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+
+;;; Implementation of the Gamma function
+
 (defmfun simpgamma (x vestigial z)
   (declare (ignore vestigial))
   (oneargcheck x)
@@ -538,7 +561,7 @@
 	   (let ((result
 		  (let ((c (* (sqrt (* 2 (float pi)))
 			      (exp (slatec::d9lgmc a)))))
-		    (let ((v (expt a (- (* .5d0 a) 0.25d0))))
+		    (let ((v (expt a (- (* .5e0 a) 0.25e0))))
 		      (* v
 			 (/ v (exp a))
 			 c)))))
@@ -547,32 +570,8 @@
 		 (merror (intl:gettext "gamma: overflow in GAMMAFLOAT."))
 		 result))))))
 
-
 (declare-top (special $numer $trigsign))
 
-;;; The Error functions Erf, Erfc, Erfi and the function Generalized Erf have 
-;;; been implemented as simplifying functions. The code is moved to the file
-;;; gamma.lisp and commented out at this place. 10/2008 DK.
-
-;(defmfun simperf (x vestigial z &aux y)
-;  (declare (ignore vestigial))
-;  (oneargcheck x)
-;  (setq y (simpcheck (cadr x) z))
-;  (cond ((zerop1 y) y)
-;	((or (floatp y) (and $numer (integerp y))) (erf (float y)))
-;	((eq y '$inf) 1)
-;	((eq y '$minf) -1)
-;	;;((and $trigsign (mminusp* y)) (neg (list '(%erf simp) (neg y))))
-;	((and $trigsign (great (neg y) y)) (neg (take '(%erf) (neg y))))
-;	(t (eqtest (list '(%erf) y) x))))
-
-
-;(defmfun erf (y)
-;  (slatec:derf (float y)))
-
-;(defmfun erfc (y)
-;  (slatec:derfc (float y)))
-
 (defmfun $zeromatrix (m n) ($ematrix m n 0 1 1))
 
 (defmfun $ematrix (m n var i j)
@@ -734,8 +733,8 @@
 	     (mul2 d b1)))))
 
 (declare-top (special $globalsolve $backsubst $dispflag
-		      $linsolve_params $%rnum_list ax linelable $linechar 
-		      $linenum sol *mosesflag))
+		      $linsolve_params $%rnum_list ax *linelabel* $linechar 
+		      $linenum *mosesflag))
 
 (defun xrutout (ax n m varl ind)
   (let (($linsolve_params (and $backsubst $linsolve_params)))
@@ -774,20 +773,20 @@
        (do ((ll zz (cdr ll)))
 	   ((null ll))
 	 (setq zzz (car ll))
-	 (setq zzz (list '(mlable)
+	 (setq zzz (list '(mlabel)
 			 (progn
 			   (if chk
 			       (setq chk nil)
 			       (incf $linenum))
 			   (let (($nolabels nil))
 			     (makelabel $linechar))
-			   linelable)
-			 (set linelable zzz)))
-	 (nconc sol (ncons linelable))
+			   *linelabel*)
+			 (set *linelabel* zzz)))
+	 (nconc sol (ncons *linelabel*))
 	 (cond ($dispflag
 		(setq tim (get-internal-run-time))
 		(mtell-open "~%~M" zzz)
 		(timeorg tim))
 	       (t
-		(putprop linelable t 'nodisp))))
+		(putprop *linelabel* t 'nodisp))))
        (return sol))))
