@@ -18,13 +18,6 @@
 
 (declare-top (special $linel))
 
-(defmvar $cursordisp t
-  "If T, causes expressions to be drawn by the displayer in logical
-	  sequence.  This only works with a console which can do cursor movement.
-	  If NIL, expressions are simply printed line by line.
-	  CURSORDISP is NIL when a WRITEFILE is in effect."
-  no-reset)
-
 (defmvar $stardisp nil
   "Causes factors of products to be separated by * when displayed.")
 
@@ -40,14 +33,6 @@
   "Causes symbols not having $ as the first character in their pnames
 	 to be preceded with a ? when displayed.")
 
-;; This may be flushed in the future if nobody dislikes the graphics crocks.
-
-(defmvar $linedisp t
-  "Causes quotients, matrices, and boxes to be drawn with straight
-	 lines, if possible.  This will work on graphic terminals or
-	 video terminals with line drawing character sets.  If enabled,
-	 the values of LMXCHAR, RMXCHAR, ABSBOXCHAR, and BOXCHAR are ignored.")
-
 (defmvar $derivabbrev nil)
 
 (defmvar $noundisp nil)
@@ -59,13 +44,6 @@
 
 (defmvar displayp nil "Is T when inside of `displa'")
 
-;; More messages which appear during the middle of display.  Different
-;; from those which appear during typein.  MOREMSG and MOREFLUSH get
-;; bound to these.
-
-(defvar d-moremsg "--More Display?--")
-(defvar d-moreflush "--Display Flushed--")
-
 ;; Parameters which control how boxes, absolute value signs,
 ;; evaluation-at-a-point bars, and matrices are drawn.
 
@@ -78,8 +56,6 @@
 ;; for each window.  Set them here, anyway, so that RETRIEVE can be called from
 ;; top level.  The size of TOP-WINDOW is wired in here.
 
-(setq smart-tty nil rubout-tty nil scrollp t)
-
 (setq linel 79. $linel 79. ttyheight 24.)
 
 (defvar linearray (make-array 80. :initial-element nil))
@@ -88,35 +64,6 @@
   (let ((*standard-output* stream))
     (displa form)))
 
-(defun maxima-draw-form (form &key (stream *standard-output*) (at-x 0) (at-y 0)
-			 $linedisp $cursordisp &aux dim-list)
-  "First try at getting an interface to allow one to draw a form at any
-  position. The at-x and at-y amount to the initial position which will be in
-  the middle left of a matrix, or the main line for a polynomial.  On a stream
-  which does no cursorpositioning it would be top left corner at the call and
-  spaced over by at-y. It can't tell where it is in the line, already so you have to tell it
-  where to begin, or if it occurs in a format command go back to last % to get offset."
-  (let ((*standard-output* stream) )
-    (unwind-protect
-	 (let ((mratp (checkrat form))
-	       (#.writefilep #.writefilep)
-	       (maxht     1) (maxdp   0) (width   0)
-	       (height    0) (depth   0) (level   0) (size   2)
-	       (break     0) (right   0) (lines   1) bkpt
-	       (bkptwd    0) (bkptht  1) (bkptdp  0) (bkptout 0)
-	       (bkptlevel 0) in-p
-	       (moreflush d-moreflush)
-	       more-^w
-	       (moremsg d-moremsg))
-	   (setq dim-list (dimension form nil 'mparen 'mparen 0 0))
-	   (cond ($cursordisp  (draw-2d (nreverse dim-list) at-x at-y))
-		 (t
-		  (draw-linear (nreverse dim-list) (+ at-x height) at-y)
-		  (loop for i downfrom (1- (length linearray)) to 0
-		     when (aref linearray i)
-		     do (output-linear-one-line i)))))
-      (fill linearray nil))))
-
 (defvar *alt-display2d* nil)
 (defvar *alt-display1d* nil)
 
@@ -133,10 +80,7 @@
 			  (height    0) (depth   0) (level   0) (size   2)
 			  (break     0) (right   0) (lines   1) bkpt
 			  (bkptwd    0) (bkptht  1) (bkptdp  0) (bkptout 0)
-			  (bkptlevel 0) in-p
-			  (moreflush d-moreflush)
-			  more-^w
-			  (moremsg d-moremsg))
+			  (bkptlevel 0) in-p)
 		      (unwind-protect
 			   (progn
 			     (setq form (dimension form nil 'mparen 'mparen 0 0))
@@ -151,6 +95,17 @@
 		 (apply *alt-display1d* form ())
 		 (linear-displa form))))))
 
+;;; (LINEAR-DISPLA <thing-to-display>)
+;;;
+;;; Display text linearly. This function should be usable in any case
+;;;  DISPLA is usable and will attempt to do something reasonable with
+;;;  its input.
+
+(defun linear-displa (form)
+  (fresh-line *standard-output*)
+  (mgrind form *standard-output*)
+  (terpri))
+
 (defmvar $display_format_internal nil
   "Setting this TRUE can help give the user a greater understanding
 	 of the behavior of maxima on certain of his problems,
@@ -622,28 +577,16 @@
 ;;    ----------------------------------
 ;; (Likewise for X2, H2, D2, W2 in the denominator)
 
-;; Hack to recycle slots on the stack.  Compiler should be doing this.
-;; Use different names to preserve sanity.
-
-(defvar x1)
-(defvar x2)
-
-(eval-when
-    #+gcl (compile load eval)
-    #-gcl (:compile-toplevel :load-toplevel :execute)
-  (setq x1 'h1 x2 'd2))
-
-
 (defun dratio (result num w1 h1 d1 den w2 h2 d2)
   (setq width (max w1 w2)
 	height (+ 1 h1 d1)
 	depth (+ h2 d2))
-  (setq #.x1 (truncate (- width w1) 2)
-	#.x2 (truncate (- width w2) 2))
+  (setq h1 (truncate (- width w1) 2)
+	d2 (truncate (- width w2) 2))
   (update-heights height depth)
-  (push `(,#.x1 ,(1+ d1) . ,num) result)
-  (push `(,(- #.x2 (+ #.x1 w1)) ,(- h2) . ,den) result)
-  (push `(,(- 0 #.x2 w2) 0) result)
+  (push `(,h1 ,(1+ d1) . ,num) result)
+  (push `(,(- d2 (+ h1 w1)) ,(- h2) . ,den) result)
+  (push `(,(- 0 d2 w2) 0) result)
   (push `(d-hbar ,width) result)
   result)
 
@@ -1184,7 +1127,8 @@
   (if (null (cddr form)) (dimension (cadr form) result lop rop 0 0)
       (dimension-nary form result)))
 
-(displa-def mlable dim-mlabel 0 0)
+(displa-def mlabel dim-mlabel 0 0)
+(setf (get 'mlabel 'wxxml) 'wxxml-mlable) ;; backwards-compatibility for wxMaxima
 
 (defvar *display-labels-p* t)
 
@@ -1199,7 +1143,7 @@
 		    w (1+ width) h height d depth)))
      (let ((level linel)) (checkbreak result w))
      (setq dummy (list 0 0))
-     (setq result (dimension (caddr form) (cons dummy result) 'mlable rop w right))
+     (setq result (dimension (caddr form) (cons dummy result) 'mlabel rop w right))
      (cond ((and (not $leftjust) (= 0 bkptout))
 	    (rplaca dummy (max 0 (- (truncate (- linel width) 2) w)))
 	    (setq width (+ (car dummy) width))))
@@ -1241,7 +1185,6 @@
          ;; MEANING OF FOLLOWING MESSAGE IS OBSCURE.
          (merror (intl:gettext "display: 'checkbreak' not found."))))
 	 (output bkpt 0)
-	 (let ((#.ttyoff (or #.ttyoff more-^w))))
 	 (setq lines (1+ lines)
 	       bkpt result bkptout bkptwd bkptwd w
 	       bkptht maxht bkptdp maxdp bkptlevel level maxht 1 maxdp 0))
@@ -1295,8 +1238,6 @@
 ;; position.  Why this is done is beyond me.  It only appears to complicate
 ;; things.
 
-;; There are two basic output functions.  OUTPUT-2D draws equations in the same
-;; order they are dimensioned, and OUTPUT-LINEAR draws equations line by line.
 ;; When a <drawing function> is invoked, the first argument passed to it is a
 ;; flag which is T for linear output and NIL for 2D output.  A
 ;; <drawing function> is also expected to return the new column position.
@@ -1310,18 +1251,13 @@
   (cond
     ;; If output is turned off to the console and no WRITEFILE is taking
     ;; place, then don't output anything.
-    ((and (or #.ttyoff more-^w) (not #.writefilep)))
-    ;; If the terminal can't do cursor movement, or we are writing
-    ;; to a WRITEFILE (#.writefilep is on) or the terminal is scrolling or
-    ;; something else random, then draw equations line by line.
+    ((and #.ttyoff (not #.writefilep)))
+    ;; Constant 80. in this test appears to be the size of LINEARRAY.
     ((> (+ bkptht bkptdp) 80.)
-     ;; IS IT STILL POSSIBLE TO EVER TRIGGER THE FOLLOWING MESSAGE ??
+     ;; I suppose we could reallocate LINEARRAY to some larger size and keep going here ...
      (merror (intl:gettext "display: expression is too tall to be displayed.")))
-    ((or (not (and smart-tty $cursordisp))
-	 #.writefilep scrollp (> (+ bkptht bkptdp) (- ttyheight 2)))
-     (output-linear (nreverse result) w))
-    ;; Otherwise, draw equations in the same order as they are dimensioned.
-    (t (output-2d (nreverse result) w))))
+    (t
+     (output-linear (nreverse result) w))))
 
 ;; Output function for terminals without cursor positioning capability.
 ;; Characters are drawn into LINEARRAY instead.  Each element of LINEARRAY is a
@@ -1336,7 +1272,6 @@
   (do ((i (1- (+ bkptht bkptdp)) (1- i)))
       ((< i 0))
     (cond ((null (aref linearray i)))
-	  (more-^w (output-linear-one-line i))
 	  (t (output-linear-one-line i)))))
 
 (defun output-linear-one-line (i)
@@ -1367,7 +1302,7 @@
    oldrow and oldcol are the starting points for the the (dx,dy) offsets
    given in the dimension string DMSTR.  It does not check that oldrow
    is big enough for possible negative y offsets in DMSTR, but BKPTDP is the
-   right global to use for  oldrow (see Draw-2d)."
+   right global to use for  oldrow."
   (do ((line))
       ((null dmstr))
     (cond ((atom (car dmstr))
@@ -1398,54 +1333,6 @@
   ;; Be sure to return this.
   oldcol)
 
-;; Output function for terminals with cursor positioning capability.  Draws
-;; equations in the order they are dimensioned.  To be efficient, it does block
-;; mode i/o into a stream called DISPLAY-FILE, set up in ALJABR;LOADER.
-;; This function is not used if a WRITEFILE is taking place.
-
-(defun output-2d (result w &aux (h 0))
-  (setq oldrow 0
-	oldcol 0
-	h (+ oldrow bkptht bkptdp))
-  (cursorpos* oldrow 0)
-  ;; Move the cursor vertically until we are at the bottom line of the
-  ;; new expression.
-  (do ()
-      ((= h oldrow))
-    (tyo* #\newline)
-    (incf oldrow))
-  (draw-2d result (- oldrow bkptdp 1) w)
-  (cursorpos* (setq h (min (- ttyheight 2) h)) 0))
-
-;; For now, cursor movement is only available on ITS and the Lisp
-;; Machine.  But define this to catch possible errors.
-
-(defun draw-2d (dmstr row col)
-  (cursorpos* row col)
-  (do ((l dmstr))
-      ((null l))
-    (cond ((integerp (car l)) (tyo* (car l)) (pop l))
-	  ((integerp (caar l))
-	   (setq col oldcol)
-	   (do ()
-	       ((or (integerp (car l)) (not (integerp (caar l)))))
-	     (cond
-	       ((null (cddar l)) (setq col (+ col (caar l))))
-	       (t (draw-2d (reverse (cddar l))
-			   (-  row (cadar l)) (+ col (caar l)))
-		  (setq col oldcol)))
-	     (pop l))
-	   (cursorpos* row col))
-	  (t (apply (caar l) nil (cdar l))
-	     (pop l)))))
-
-;; Crude line graphics.  The interface to a graphics device is via the
-;; functions LG-SET-POINT, LG-DRAW-VECTOR and via the
-;; LG-CHARACTER specials.
-;; LG-CHARACTER-X and LG-CHARACTER-Y give the width and height of a character
-;; in pixels, and the -2 variables are simply those numbers divided by 2.  LG
-;; stands for "Line Graphics".  See MAXSRC;ARDS for a sample ctl.
-
 ;; Special symbol drawing functions -- lines, boxes, summation signs, etc.
 ;; Every drawing function must take at least one argument.  The first
 ;; argument is T if equations must be printed line-by-line.  Otherwise,
@@ -1459,13 +1346,10 @@
 ;; program.)
 
 (defun d-hbar (linear? w &optional (char #\-) &aux nl)
-  (cond (linear?
-	 (dotimes (i w)
-	   (push char nl))
-	 (draw-linear nl oldrow oldcol))
-	(t
-	 (dotimes (i w)
-	   (tyo* char)))))
+  (declare (ignore linear?))
+  (dotimes (i w)
+    (push char nl))
+  (draw-linear nl oldrow oldcol))
 
 ;; Notice that in all of the height computations, an offset of 2 is added or
 ;; subtracted to the y-dimension.  This is to get the lines to fit within the
@@ -1473,37 +1357,27 @@
 ;; the equation editor.
 
 (defun d-vbar (linear? h d &optional (char #\|))
-  (cond (linear?
-	 (setq d (- d))
-	 (do ((i (- h 2) (1- i))
-	      (nl `((0 ,(1- h) ,char))))
-	     ((< i d) (draw-linear (nreverse nl) oldrow oldcol))
-	   (push `(-1 ,i ,char) nl)))
-	(t
-	 (cursorpos* (+ oldrow 1 (- h)) oldcol)
-	 (tyo* char)
-	 (dotimes (i (+ h d -1))
-	   (cursorpos* (1+ oldrow) (1- oldcol))
-	   (tyo* char))
-	 (cursorpos* (- oldrow d) oldcol))))
+  (declare (ignore linear?))
+  (setq d (- d))
+  (do ((i (- h 2) (1- i))
+       (nl `((0 ,(1- h) ,char))))
+      ((< i d) (draw-linear (nreverse nl) oldrow oldcol))
+    (push `(-1 ,i ,char) nl)))
 
 (defun d-integralsign (linear? &aux dmstr)
+  (declare (ignore linear?))
   (setq dmstr `((0 2 #\/) (-1 1 #\[) (-1 0 #\I) (-1 -1 #\]) (-1 -2 #\/)))
-  (if linear?
-      (draw-linear dmstr oldrow oldcol)
-      (draw-2d dmstr oldrow oldcol)))
+  (draw-linear dmstr oldrow oldcol))
 
 (defun d-prodsign (linear? &aux dmstr)
+  (declare (ignore linear?))
   (setq dmstr '((0 2 #\\ (d-hbar 3 #\=) #\/) (-4 0) (d-vbar 2 1 #\!) #\space (d-vbar 2 1 #\!) (1 0)))
-  (if linear?
-      (draw-linear dmstr oldrow oldcol)
-      (draw-2d dmstr oldrow oldcol)))
+  (draw-linear dmstr oldrow oldcol))
 
 (defun d-sumsign (linear? &aux dmstr)
+  (declare (ignore linear?))
   (setq dmstr '((0 2 (d-hbar 4 #\=)) (-4 1 #\\) #\> (-2 -1 #\/)	(-1 -2 (d-hbar 4 #\=))))
-  (if linear?
-      (draw-linear dmstr oldrow oldcol)
-      (draw-2d dmstr oldrow oldcol)))
+  (draw-linear dmstr oldrow oldcol))
 
 ;; Notice how this calls D-VBAR in the non-graphic case.  The entire output
 ;; side should be structured this way, with no consing of intermediate
@@ -1517,6 +1391,7 @@
 ;; There is wired knowledge of character offsets here.
 
 (defun d-box (linear? h d w body &aux (char 0) dmstr) ;char a char?
+  (declare (ignore linear?))
   (setq char (car (coerce $boxchar 'list)))
   (setq dmstr `((0 ,h (d-hbar ,(+ 2 w) ,char))
 		(,(- (+ w 2)) 0)
@@ -1525,46 +1400,4 @@
 		(,(- (1+ w)) ,(- (1+ d)) (d-hbar ,(+ w 2) ,char))
 		(-1 0)
 		(d-vbar ,h ,d ,char)))
-  (if linear?
-      (draw-linear dmstr oldrow oldcol)
-      (draw-2d dmstr oldrow oldcol)))
-
-;; Primitive functions for doing equation drawing.
-
-;; Position the cursor at a given place on the screen.  %TDMV0 does
-;; absolute cursor movement.
-
-(defun cursorpos* (row col)
-  (setq oldrow row oldcol col))
-
-;; This function is transmitting ITS output buffer codes in addition to
-;; standard ascii characters.  See INFO;ITSTTY > for documentation.  This
-;; should convert tabs to direct cursor positioning commands since otherwise
-;; they get stuffed down the raw stream and appear as gammas on sail consoles
-;; and lose completely on terminals which can't tab.  Backspace also loses,
-;; but its nearly impossible to get a string with backspace in it in Macsyma.
-;; Also, DISPLA can't dimension it correctly.
-
-(defun tyo* (char)
-  (cond ((char= #\backspace char)
-	 (decf oldcol))			;Backspace
-	((char< char #.(code-char 128))
-	 (incf oldcol)))		;Printing graphic
-  (write-char char))
-
-
-;; Things to do:
-;; * Rewrite TYO* and CURSORPOS* to be "stream" oriented, i.e. they
-;;   either draw directly to the screen or into the linearray depending
-;;   upon the mode of output.  This way, the HBAR and VBAR drawing functions
-;;   can be written only in terms of TYO*, etc. and never cons.
-;;   DRAW-LINEAR and DRAW-2D can be merged into a single function.
-;; * Instead of calling NREVERSE from OUTPUT, call a function which
-;;   reverses at all levels and remove calls to REVERSE from DRAW-LINEAR
-;;   and DRAW-2D.
-;; * Dimension functions should know whether the output must be linear.
-;;   This way they can do variable sized summation and integral signs,
-;;   graphical square root or SQRT(X), %PI  , >=  , etc.
-;;   These are situations where the size of the dimensioned
-;;   result depends upon the form of the output.
-;; * Fix display of MLABOX for graphic consoles.
+  (draw-linear dmstr oldrow oldcol))
