@@ -537,13 +537,14 @@
 		     ;; the original order.  Fortunately, this doesn't
 		     ;; have to be very fast, so we do it very naively.
 		     (dolist (test (mapcar #'remove-dollarsign (cdr tests)))
-		       (when (find test (cdr $testsuite_files)
-				   :key #'(lambda (x)
-					    (maxima-string (if (listp x)
-							       (second x)
-							       x)))
-				   :test #'string=)
-			 (push test results)))
+		       (let ((matching-test (find test (cdr $testsuite_files)
+						  :key #'(lambda (x)
+							   (maxima-string (if (listp x)
+									      (second x)
+									      x)))
+						  :test #'string=)))
+			 (when matching-test
+			   (push matching-test results))))
 		     (nreverse results)))
 		  (t
 		   (cdr $testsuite_files))))))
@@ -565,54 +566,73 @@
       (load (concatenate 'string *maxima-testsdir* "/" "testsuite.lisp")))
     (let ((error-break-file)
 	  (testresult)
-	  (tests-to-run (intersect-tests tests))
+	  (tests-to-run (intersect-tests (cond ((consp tests) tests)
+					       (tests (list '(mlist) tests)))))
 	  (test-count 0)
 	  (total-count 0)
 	  (error-count 0))
-      (time 
-       (loop with errs = '() for testentry in tests-to-run
-	     do
-	     (if (atom testentry)
-		 (progn
-		   (setf test-file testentry)
-		   (setf expected-failures nil))
-		 (progn
-		   (setf test-file (second testentry))
-		   (setf expected-failures (cddr testentry))))
-  
-	     (format t (intl:gettext "Running tests in ~a: ") (if (symbolp test-file)
-						   (subseq (print-invert-case test-file) 1)
-						   test-file))
-	     (or (errset
-		  (progn
-		    (multiple-value-setq (testresult test-count)
-		      (test-batch ($file_search test-file $file_search_tests)
-				  expected-failures
-				  :show-expected display_known_bugs
-				  :show-all display_all
-				  :showtime time))
-		    (setf testresult (rest testresult))
-		    (incf total-count test-count)
-		    (when testresult
-		      (incf error-count (length (cdr testresult)))
-		      (setq errs (append errs (list testresult))))))
-		 (progn
-		   (setq error-break-file (format nil "~a" test-file))
-		   (setq errs 
-			 (append errs 
-				 (list (list error-break-file "error break"))))
-		   (format t (intl:gettext "~%Caused an error break: ~a~%") test-file)))
-	     finally (cond ((null errs) 
-			    (format t (intl:gettext "~%~%No unexpected errors found out of ~:D tests.~%") total-count))
-			   (t (format t (intl:gettext "~%Error summary:~%"))
+      (flet
+	  ((testsuite ()
+	     (loop with errs = 'nil
+		   for testentry in tests-to-run
+		   do (if (atom testentry)
+			  (progn
+			    (setf test-file testentry)
+			    (setf expected-failures nil))
+			  (progn
+			    (setf test-file (second testentry))
+			    (setf expected-failures (cddr testentry))))
+		      (format t
+			      (intl:gettext "Running tests in ~a: ")
+			      (if (symbolp test-file)
+				  (subseq (print-invert-case test-file) 1)
+				  test-file))
+		      (or
+			(errset
+			  (progn
+			    (multiple-value-setq (testresult test-count)
+			      (test-batch ($file_search test-file $file_search_tests)
+					  expected-failures :show-expected display_known_bugs
+					  :show-all display_all :showtime time))
+			    (setf testresult (rest testresult))
+			    (incf total-count test-count)
+			    (when testresult
+			      (incf error-count (length (cdr testresult)))
+			      (setq errs (append errs (list testresult))))))
+			(progn
+			  (setq error-break-file (format nil "~a" test-file))
+			  (setq errs
+				(append errs
+					(list (list error-break-file "error break"))))
+			  (format t
+				  (intl:gettext "~%Caused an error break: ~a~%")
+				  test-file)))
+		   finally (cond
+			     ((null errs)
+			      (format t
+				      (intl:gettext
+				       "~%~%No unexpected errors found out of ~:d tests.~%")
+				      total-count))
+			     (t
+			      (format t (intl:gettext "~%Error summary:~%"))
 			      (mapcar
 			       #'(lambda (x)
 				   (let ((s (if (> (length (rest x)) 1) "s" "")))
-				     (format t (intl:gettext "Error~a found in ~a, problem~a:~%~a~%")
-					     s (first x) s (sort (rest x) #'<))))
+				     (format t
+					     (intl:gettext
+					      "Error~a found in ~a, problem~a:~%~a~%")
+					     s
+					     (first x)
+					     s
+					     (sort (rest x) #'<))))
 			       errs)
-			      (format t (intl:gettext "~&~:D test~P failed out of ~:D total tests.~%")
-				      error-count error-count total-count)))))))
+			      (format t
+				      (intl:gettext
+				       "~&~:d test~p failed out of ~:d total tests.~%")
+				      error-count
+				      error-count
+				      total-count))))))
+      (time (testsuite)))))
   '$done)
 
 ;; Convert a list of Maxima "keyword" arguments into the corresponding
