@@ -110,10 +110,10 @@
   (setq x ($totaldisrep x))
   (and (not (atom x)) (eq (caar x) 'mequal) (newvar (cadr x)))
   (newvar (setq x (meqhk x)))
-  (unless varlist (merror "Improper polynomial"))
+  (unless varlist (merror (intl:gettext "tellrat: argument must be a polynomial; found: ~M") x))
   (setq algvar (car (last varlist)))
   (setq x (p-terms (primpart (cadr (ratrep* x)))))
-  (unless (equal (pt-lc x) 1) (merror "Minimal polynomial must be monic"))
+  (unless (equal (pt-lc x) 1) (merror (intl:gettext "tellrat: minimal polynomial must be monic.")))
   (do ((p (pt-red x) (pt-red p)))
       ((ptzerop p))
     (setf (pt-lc p) (pdis (pt-lc p))))
@@ -261,8 +261,6 @@
 	  ($multthru ans))
 	ans)))
 
-(defvar alpha nil)
-
 (defmfun factor (e &optional (mp nil mp?))
   (let ((tellratlist nil)
 	(varlist varlist)
@@ -271,7 +269,7 @@
 	($negdistrib $negdistrib))
     (prog (fn var mm* mplc* intbs* alflag minpoly* alpha p algfac*
 	   $keepfloat $algebraic cargs)
-       (declare (special cargs fn))
+       (declare (special cargs fn alpha))
        (unless (member $gcd *gcdl* :test #'eq)
 	 (setq $gcd (car *gcdl*)))
        (let ($ratfac)
@@ -291,7 +289,7 @@
 		(when (or (pcoefp minpoly*)
 			  (not (univar (cdr minpoly*)))
 			  (< (cadr minpoly*) 2))
-		  (merror "The second argument to `factor' must be a non-linear, univariate polynomial: ~M" alpha))
+		  (merror (intl:gettext "factor: second argument must be a nonlinear, univariate polynomial; found: ~M") alpha))
 		(setq alpha (pdis (list (car minpoly*) 1 1))
 		      mm* (cadr minpoly*))
 		(unless (equal (caddr minpoly*) 1)
@@ -362,7 +360,7 @@
     (when m?
       (setq modulus m)
       (when (or (not (integerp modulus)) (zerop modulus))
-	(merror "Improper value for `modulus':~%~M" modulus)))
+	(merror (intl:gettext "polymod: modulus must be a nonzero integer; found: ~M") modulus)))
     (when (minusp modulus)
       (setq modulus (abs modulus)))
     (mod1 p)))
@@ -558,7 +556,7 @@
 (defun rget (genv)
   (cons (if (and $ratwtlvl
 		 (or (fixnump $ratwtlvl)
-		     (merror "Illegal value for `ratwtlvl':~%~M" $ratwtlvl))
+		     (merror (intl:gettext "rat: 'ratwtlvl' must be an integer; found: ~M") $ratwtlvl))
 		 (> (or (get genv '$ratweight) -1) $ratwtlvl))
 	    (pzero)
 	    (pget genv))
@@ -863,7 +861,7 @@
 
 (defmvar $ratprint t)
 
-(defmvar $ratepsilon 2e-8)
+(defmvar $ratepsilon 2e-15)
 
 ;; This control of conversion from float to rational appears to be explained
 ;; nowhere. - RJF
@@ -903,8 +901,8 @@
 		  (cons num den))))))))
 
 (defun prepfloat (f)
-  (cond (modulus (merror "Floating point meaningless unless `modulus' = `false'"))
-	($ratprint (mtell "~&rat: replaced ~A by" f)))
+  (cond (modulus (merror (intl:gettext "rat: can't rationalize ~M when modulus = ~M") f modulus))
+	($ratprint (mtell (intl:gettext "~&rat: replaced ~A by") f)))
   (setq f (maxima-rationalize f))
   (when $ratprint
     (mtell " ~A/~A = ~A~%"  (car f) (cdr f) (fpcofrat1 (car f) (cdr f))))
