@@ -21,35 +21,20 @@
   (setq old-ibase *read-base* old-base *print-base*)
   (setq *read-base* 10. *print-base* 10.))
 
-(defmvar mopl nil)
+;; Store build-in operators, which get additional properties.
+;; These operators aren't killed by the function kill-operator.
+(defvar *mopl* nil)
 
-(declare-top  (special $debugmode $lasttime $disptime
-		       bindlist loclist errset $labels linelable $filesize
-		       st rephrase $dispflag refchkl baktrcl
-		       dskfnp dsksavep *rset ^q lf tab ff cr
-		       $values $functions $arrays $aliases $gradefs $dependencies
-		       $rules $props $ratvars $ratvarswitch *mdebug* errbrksw errcatch
-		       varlist genvar $device $filename $filenum
-		       $gensumnum checkfactors $features featurel $backtrace
-		       $weightlevels tellratlist $dontfactor $infolists
-		       $dskall allbutl lisperrprint dcount thistime
-		       $nolabels dispflag saveno mcatch brklvl savefile
-		       $%% $error *in-translate-file*
-		       lessorder greatorder $errorfun mbreak reprint pos $strdisp
-		       $dskuse smart-tty more-^w oldst
-		       $loadprint opers *ratweights $ratweights quitmsg
-		       loadf $grind $stringdisp $lispdisp defaultf
-		       state-pdl command
-		       transp $contexts $setcheck $macros
-		       autoload))
-
-(defvar $prompt '_)
-
-
-(mapc #'(lambda (x) (putprop (car x) (cadr x) 'opalias))
-      '((+ $+) (- $-) (* $*) (// $//) (^ $^) (|.| |$.|) (< $<) (= $=)
-	(> $>) (|(| |$(|) (|)| |$)|) (|[| |$[|) (|]| |$]|) (|,| |$,|) (|:| |$:|)
-	(|!| |$!|) (|#| |$#|) (|'| |$'|) (|;| |$;|)))
+(declare-top  (special bindlist loclist errset *rset ^q lf tab ff cr
+		       $values $functions $arrays $gradefs $dependencies
+		       $rules $props $ratvars
+		       varlist genvar
+		       $gensumnum checkfactors $features featurel
+		       $weightlevels tellratlist $dontfactor
+		       dispflag savefile $%% $error
+		       opers *ratweights $ratweights
+		       $stringdisp $lispdisp command
+		       transp $contexts $setcheck $macros autoload))
 
 (mapc #'(lambda (x) (setf (symbol-value (car x))
 			 (cond ((char< (cadr x) #.(code-char 160.))
@@ -57,51 +42,50 @@
 			       (t (cadr x)))))
       '((tab #\tab) (lf #\linefeed) (ff #\page) (cr #\return) (sp #\space)))
 
-(setq $lasttime '((mlist) 0 0)
-      thistime 0
-      $disptime nil)
+(defvar thistime 0)
+(defvar *refchkl* nil)
+(defvar *mdebug* nil)
+(defvar *baktrcl* nil)
+(defvar errbrksw nil)
+(defvar errcatch nil)
+(defvar mcatch nil)
+(defvar brklvl -1)
+(defvar allbutl nil)
+(defvar loadf nil)
+(defvar lessorder nil)
+(defvar greatorder nil)
+(defvar *in-translate-file* nil)
+(defvar *linelabel* nil)
+(defvar rephrase nil)
+(defvar st nil)
+(defvar oldst nil)
+(defvar reprint nil)
+(defvar pos nil)
+(defvar dcount 0)
+(defvar dskfnp nil)
+(defvar saveno 0)
+(defvar quitmsg  " ")
+(defvar lisperrprint t)
 
-(setq $strdisp t $grind nil)
+(defvar state-pdl (ncons 'lisp-toplevel))
 
-(setq refchkl nil
-      *mdebug* nil
-      baktrcl nil
-      errbrksw nil
-      mbreak nil
-      $errorfun nil
-      errcatch nil
-      mcatch nil
-      brklvl -1
-      allbutl nil
-      loadf nil
-      $backtrace '$backtrace)
+(defmvar $disptime nil)
+(defmvar $strdisp t)
+(defmvar $grind nil)
+(defmvar $backtrace '$backtrace)
+(defmvar $debugmode nil)
+(defmvar $poislim 5)
+(defmvar $loadprint nil)
+(defmvar $nolabels nil)
+(defmvar $aliases '((mlist simp)))
 
-(setq *in-translate-file* nil)
+(defmvar $infolists
+  '((mlist simp) $labels $values $functions $macros $arrays
+                 $myoptions $props $aliases $rules $gradefs
+                 $dependencies $let_rule_packages $structures))
 
-(setq $debugmode nil $pagepause nil $poislim 5)
-
-(setq $loadprint nil)
-
-(setq $nolabels nil $aliases '((mlist simp)) lessorder nil greatorder nil)
-
-(setq $infolists '((mlist simp) $labels $values $functions $macros $arrays
-		   $myoptions $props $aliases $rules $gradefs
-		   $dependencies $let_rule_packages $structures))
-
-(setq $labels (list '(mlist simp)))
-
-(setq $dskuse nil $device '$dsk $dispflag t linelable nil)
-
-(setq rephrase nil st nil oldst nil reprint nil pos nil)
-
-(setq dcount 0 $filenum 0 $storenum 1000. $filesize 16. $dskall t
-      dskfnp nil dsksavep nil saveno 0)
-
-(setq quitmsg  " "
-      more-^w nil
-      lisperrprint t)
-
-(setq state-pdl (ncons 'lisp-toplevel))
+(defmvar $labels (list '(mlist simp)))
+(defmvar $dispflag t)
 
 (defmvar $% '$% "The last out-line computed, corresponds to lisp *"
 	 no-reset)
@@ -118,52 +102,39 @@
 (defmvar $linenum 1 "the line number of the last expression."
 	 fixnum no-reset)
 
-(defmvar $direc 'jrmu
-  "The default file directory for `save', `store', `fassave', and `stringout'."
-  no-reset)
-
 (defmvar $file_output_append nil
   "Flag to tell file-writing functions whether to append or clobber the output file.")
 
 (defmvar user-timesofar nil)
 
-(defvar moremsg "--Pause--")
-(defvar morecontinue "--Continued--")
-(defvar moreflush nil)
-(defmvar $morewait nil "needs to be documented" no-reset)
+;; This version of meval* makes sure, that the facts from the global variable
+;; locals are cleared with a call to clearsign. The facts are added by asksign
+;; and friends. The function meval* is only used for top level evaluations.
+;; For other cases the function meval can be used.
 
-(defmvar $showtime nil)
+(defmvar $ratvarswitch t) ; If T, start an evaluation with a fresh list VARLIST.
 
-(defmvar aliaslist nil
-  "is used by the `makeatomic' scheme which has never been completed"
-  no-reset)
-
-(defun sys-gctime ()
-  (status gctime))
-
-(defmvar $showtime nil)
-
-(defmfun meval* (test)
-  (let (refchkl baktrcl checkfactors)
-    (prog2 (if $ratvarswitch (setq varlist (cdr $ratvars)))
-	(meval test)
-      (clearsign))))
+(defun meval* (expr)
+  ;; Make sure that clearsign is called after the evaluation.
+  (unwind-protect
+    (let (*refchkl* *baktrcl* checkfactors)
+      (if $ratvarswitch (setq varlist (cdr $ratvars)))
+      (meval expr))
+    ;; Clear the facts from asksign and friends.
+    (clearsign)))
 
 (defmfun makelabel (x)
-  (when (and $dskuse (not $nolabels) (> (incf dcount) $filesize))
-    (setq dcount 0)
-    (dsksave))
-  (setq linelable ($concat '|| x $linenum))
+  (setq *linelabel* ($concat '|| x $linenum))
   (unless $nolabels
     (when (or (null (cdr $labels))
-	      (when (member linelable (cddr $labels) :test #'equal)
-		(setf $labels (delete linelable $labels :count 1 :test #'eq)) t)
-	      (not (eq linelable (cadr $labels))))
-      (setq $labels (cons (car $labels) (cons linelable (cdr $labels))))))
-  linelable)
+	      (when (member *linelabel* (cddr $labels) :test #'equal)
+		(setf $labels (delete *linelabel* $labels :count 1 :test #'eq)) t)
+	      (not (eq *linelabel* (cadr $labels))))
+      (setq $labels (cons (car $labels) (cons *linelabel* (cdr $labels))))))
+  *linelabel*)
 
 (defmfun printlabel ()
-  (mtell-open "(~A) " (subseq (print-invert-case linelable) 1)))
+  (mtell-open "(~A) " (subseq (print-invert-case *linelabel*) 1)))
 
 (defmfun mexploden (x)
   (let (*print-radix*
@@ -186,7 +157,7 @@
      (unwind-protect
 	  (progn
 	    (fresh-line)
-	    (princ (stripdollar $prompt))
+	    (princ (break-prompt))
 	    (finish-output)
 	    (return (char= (tyi*) #\newline)))
        (clear-input)))))
@@ -194,38 +165,32 @@
 (defun checklabel (x)	; CHECKLABEL returns T iff label is not in use
   (not (or $nolabels
 	   (= $linenum 0)
-	   (boundp (intern (format nil "~a~a"x $linenum))))))
+	   (boundp ($concat '|| x $linenum)))))
 
 (defun gctimep (timep tim)
-  (cond ((and (eq timep '$all) (not (zerop tim))) (princ "Totaltime= ") t)
-	(t (princ "Time= ") nil)))
-
-(defun display* (&aux (ret nil) (tim 0))
-  (setq tim (get-internal-run-time)
-	ret (let ((errset 'errbreak2) (thistime -1))
-	      (errset (displa (list '(mlable) linelable $%)))))
-  (if (null ret) (mtell "~%Error during display~%"))
-  (when $disptime
-    (mtell-open "Displaytime= ~A sec.~%" (/ (float (- (get-internal-run-time) tim))
-					    internal-time-units-per-second)))
-  ret)
+  (cond ((and (eq timep '$all) (not (zerop tim))) (princ (intl:gettext "Total time = ")) t)
+	(t (princ (intl:gettext "Time = ")) nil)))
 
 ; Following GENERIC-AUTOLOAD is copied from orthopoly/orthopoly-init.lisp.
 ; Previous version didn't take Clisp, CMUCL, or SBCL into account.
 
+(defvar *autoloaded-files* ())
+
 (defun generic-autoload (file &aux type)
-  (setq file (pathname (cdr file)))
-  (setq type (pathname-type file))
-  (let ((bin-ext #+gcl "o"
-	 #+cmu (c::backend-fasl-file-type c::*target-backend*)
-	 #+clisp "fas"
-	 #+allegro "fasl"
-	 #+openmcl (pathname-type ccl::*.fasl-pathname*)
-	 #+lispworks (pathname-type (compile-file-pathname "foo.lisp"))
-	 #-(or gcl cmu clisp allegro openmcl lispworks) ""))
-    (if (member type (list bin-ext "lisp" "lsp")  :test 'equalp)
-      #-sbcl (load file) #+sbcl (with-compilation-unit nil (load file))
-      ($load file))))
+  (unless (member file *autoloaded-files* :test #'equal)
+    (push file *autoloaded-files*)
+    (setq file (pathname (cdr file)))
+    (setq type (pathname-type file))
+    (let ((bin-ext #+gcl "o"
+		   #+cmu (c::backend-fasl-file-type c::*target-backend*)
+		   #+clisp "fas"
+		   #+allegro "fasl"
+		   #+openmcl (pathname-type ccl::*.fasl-pathname*)
+		   #+lispworks (pathname-type (compile-file-pathname "foo.lisp"))
+		   #-(or gcl cmu clisp allegro openmcl lispworks) ""))
+      (if (member type (list bin-ext "lisp" "lsp")  :test 'equalp)
+	  #-sbcl (load file) #+sbcl (with-compilation-unit nil (load file))
+	  ($load file)))))
 
 (defvar autoload 'generic-autoload)
 
@@ -234,14 +199,10 @@
   (let ((file (get func 'autoload)))
     (if file (funcall autoload (cons func file)))))
 
-(defmfun load-file (file)
-  ($load (to-macsyma-namestring file)))
-
 (defmspec $loadfile (form)
   (loadfile (namestring (maxima-string (meval (cadr form)))) nil
 	    (not (member $loadprint '(nil $autoload) :test #'equal))))
 
-
 (defun $setup_autoload (filename &rest functions)
   (let ((file ($file_search filename)))
     (dolist (func functions)
@@ -265,42 +226,24 @@
   (or (mgetl func '(mexpr mmacro))
       (getl func '(translated-mmacro mfexpr* mfexpr*s))))
 
-(defmfun filenamel (file)
-  (cond ((atom file) (setq file (ncons file)))
-	(($listp file) (setq file (cdr file)))
-	(t (merror "Not a proper filename ~M" file)))
-  (filestrip file))
-
-
 (defmfun loadfile (file findp printp &aux (saveno 0))
   (and findp (member $loadprint '(nil $loadfile) :test #'equal) (setq printp nil))
   ;; Should really get the truename of FILE.
-  (if printp (format t "~%~A being loaded.~%" file))
+  (if printp (format t (intl:gettext "loadfile: loading ~A.~%") file))
   (let* ((path (pathname file))
+	 ($load_pathname path)
 	 (tem (errset #-sbcl (load (pathname file)) #+sbcl (with-compilation-unit nil (load (pathname file))))))
-    (or tem (merror "Load failed for ~A" (namestring path)))
+    (or tem (merror (intl:gettext "loadfile: failed to load ~A") (namestring path)))
     (namestring path)))
 
 (defun $directory (path)
   (cons '(mlist) (mapcar 'namestring (directory ($filename_merge path)))))
 
-(defmfun truefname (file)
-  (probe-file file))
-
-(defmfun carfile (file)		       ; FILE is in OldIO list format.
-  (if (= (length file) 3) (cdr file) file))
-
-;; SPECP is T if the file is being batched for TRANSL, or $LOAD,
-;;	or some other special purpose.
-
-(defmacro filepos-check ()
-  `(if specp (setq filepos (filepos file-obj))))
-
 (defmspec $kill (form)
+  (clear)	;; get assume db into consistent state
   (mapc #'kill1 (cdr form))
   '$done)
 
-
 ;;; The following *builtin- variables are used to keep/restore builtin
 ;;; symbols and values during kill operations. Their values are set at
 ;;; the end of init-cl.lisp, after all symbols have been defined.
@@ -311,6 +254,7 @@
 (defvar *builtin-$rules* nil)
 (defvar *builtin-symbols-with-values* nil)
 (defvar *builtin-symbol-values* (make-hash-table))
+(defvar *builtin-numeric-constants* '($%e $%pi $%phi $%gamma))
 
 (defun kill1-atom (x)
   (let ((z (or (and (member x (cdr $aliases) :test #'equal) (get x 'noun)) (get x 'verb))))
@@ -335,6 +279,7 @@
 			 (remove-transl-fun-props x)
 			 (remove-transl-array-fun-props x)))
       (when (not (get x 'sysconst))
+	(remprop x 'lineinfo)
 	(remprop x 'mprops))
       (dolist (u '(bindtest nonarray evfun evflag opers special mode))
 	(remprop x u))
@@ -344,9 +289,12 @@
 	    (remprop x 'operators)))
       (when (member x (cdr $props) :test #'equal)
 	(remprop x 'sp2)
-	(killframe x))
+	(killframe x)
+	(i-$remove (list x $features)))
       (let ((y (get x 'op)))
-	(when (and y (not (member y mopl :test #'equal)) (member y (cdr $props) :test #'equal))
+        (when (and y 
+                   (not (member y *mopl* :test #'equal))
+                   (member y (cdr $props) :test #'equal))
 	  (kill-operator x)))
       (remalias x nil)
       (setf $arrays (delete x $arrays :count 1 :test #'eq))
@@ -372,6 +320,8 @@
 		 (gethash x *builtin-symbol-props*))
 	(setf (symbol-plist x)
 	      (copy-tree (gethash x *builtin-symbol-props*))))
+      (when (member x *builtin-numeric-constants*)
+	(initialize-numeric-constant x))	;; reset db value for $%pi, $%e, etc
       (if z (kill1 z)))))
 
 (defmfun kill1 (x)
@@ -464,8 +414,14 @@
 		    t)
 		 (transp (setf (symbol-value x) x) t)
 		 ((eq x '$default_let_rule_package) t)
+		 ;; Next case: X is bound to itself but X is not on values list.
+		 ;; Translation code does that; I don't know why.
+		 ;; Silently let it stand and hope it doesn't cause trouble.
+		 ((eq (symbol-value x) x) t)
 		 (t
-		  (mtell "Warning: Illegal `remvalue' attempt:~%~M" x) nil))))))
+		  (mtell (intl:gettext "remvalue: ~M doesn't appear to be a known variable; just unbind it anyway.~%") x)
+		  (makunbound x)
+		  t))))))
 
 (defmfun ruleof (rule)
   (or (mget rule 'ruleof)
@@ -482,81 +438,6 @@
   (declare (ignore assign-var))
   (setq *mdebug* (setq *rset y)))
 
-(defun retrieve1 (a b &aux (eof '(nil)))
-  (let ((*mread-prompt* b) r )
-    (declare (special *mread-prompt*))
-    (catch 'macsyma-quit
-      (tagbody
-       top
-	 (setq r (dbm-read (or a *terminal-io*) nil eof))
-	 (cond ((and (consp r) (keywordp (car r)))
-		(let ((value (break-call (car r) (cdr r) 'break-command)))
-		  (if (eq value :resume)
-		      (return-from retrieve1 '$exit))
-		  (go top))))))
-    (nth 2 r)))
-
-(defmfun errbreak (y)		       ; The ERRSET interrupt function
-  (cond
-    (*mdebug*
-     ((lambda (brklvl varlist genvar errbrkl linelable)
-	(declare (special $help))
-	(prog (x ^q #.ttyoff o^r tim $%% $backtrace retval oldst)
-	   (setq  errset 'errbreak1)
-	   (setq tim (get-internal-run-time)
-		 $%% '$%%
-		 ;; just in case baktrcl is cons'd on the stack
-		 $backtrace (cons '(mlist simp) (copy-list baktrcl)))
-	   (setq o^r #.writefilep #.writefilep (and #.writefilep (not dskfnp)))
-	   (cond ((eq y 'noprint))
-		 (t
-		  (mterpri)
-		  (if y (princ 'macsyma-break) (princ 'error-break))
-		  (unless (zerop brklvl) (princ " level ") (princ brklvl))
-		  (princ " Type exit; to quit, help; for more help.")))
-	   (setq $help
-		 "BACKTRACE; will give a successive list of forms
- (you must have already set ?DEBUG:ALL; for BACKTRACE to record)
-     LISP; goes to lisp
-     TOPLEVEL; goes all the way to top level
-     EXIT; exits one level of the error break")
-	   (mterpri)
-	   a    (cond
-		  ((null
-		    (catch 'macsyma-break
-		      (let ((state-pdl (cons 'macsyma-break state-pdl)))
-			(errset
-			 (cond ((eq (setq x
-					  (retrieve1 nil
-						     (if y "_ " "(debug) "
-							 ))) '$exit)
-				(timeorg tim)
-				(setq retval 'exit) (go end))
-			       ((eq x '$lisp)
-				(setq retval 'lisp)
-				(go end))
-			       ((eq x '$toplevel)
-				(cond ((catch 'mbreak
-					 (let (st oldst rephrase
-						  (mbreak (cons bindlist loclist)))
-					   (incf $linenum)
-					   (continue)))
-				       (go end))
-				      (t (mtell-open "Back to the break~%"))))
-			       (t (let (($dispflag dispflag)) (setq $%% (meval x)))
-				  (if dispflag (displa $%%) (mterpri))))))))
-		   (errlfun1 errbrkl)
-		   (mtell-open "~%(Still in break loop)~%")))
-	   (go a)
-	   end  (unless (eq y 'noprint)
-		  (princ "Exited from the break ")
-		  (if (not (zerop brklvl)) (princ brklvl))
-		  (mterpri)
-		  )
-	   (if o^r (setq #.writefilep t))
-	   (return retval)))
-      (1+ brklvl) varlist genvar (cons bindlist loclist) linelable))))
-
 (defun errbreak1 (ign)
   (declare (ignore ign))
   nil)					; Used to nullify ERRSETBREAKs
@@ -566,37 +447,6 @@
   (let ((state-pdl (cons 'lisp-break state-pdl)))
     (break "erst ~S" '(errbrksw))))
 
-(defmspec $tobreak (x)
-  (if mbreak (throw 'mbreak (cdr x))
-      (merror "`tobreak' may be used only within a Maxima break.")))
-
-(defun errlfun (x)
-  (when (null (errset (progn
-			(if loadf
-			    (setq defaultf loadf
-				  loadf nil)))))
-    (setq ^q nil)
-    (mtell-open "~%`errlfun' has been clobbered."))
-  (if $errorfun
-      (if (null (errset (mapply1 $errorfun nil $errorfun nil)))
-	  (mtell "~%Incorrect `errorfun'")))
-  (when (null
-	 (errset (progn
-		   (if (not (eq x 'mquit))
-		       (supunbind))
-		   (clearsign))))
-    (setq ^q nil)
-    (mtell-open "~%`errlfun' has been clobbered."))
-  (when (null x)
-    (princ quitmsg)
-    (setq quitmsg " ")))
-
-(defun supunbind nil
-  (munbind (reverse bindlist))
-  (do ()
-      ((null loclist))
-    (munlocal)))
-
 (defmfun errlfun1 (mpdls)
   (do ((l bindlist (cdr l))
        (l1))
@@ -620,17 +470,12 @@
 
 (defmfun fexprcheck (form)
   (if (or (null (cdr form)) (cddr form))
-      (merror "~:M takes just one argument." (caar form))
+      (merror (intl:gettext "~:M: expected just one argument; found: ~M") (caar form) form)
       (cadr form)))
 
 (defmfun nonsymchk (x fn)
   (unless (symbolp x)
-    (merror "The argument to ~:M must be a symbolic name:~%~M" fn x)))
-
-(defmfun prinl (l)
-  (dolist (x l)
-    (princ x)
-    (write-char #\space)))
+    (merror (intl:gettext "~:M: argument must be a symbol; found: ~M") fn x)))
 
 (defmfun $print (&rest args)
   (if (null args)
@@ -643,6 +488,7 @@
 	(cadr (reverse l)))))
 
 (defmspec $playback (x)
+  (declare (special $showtime))
   (setq x (cdr x))
   (let ((state-pdl (cons 'playback state-pdl)))
     (prog (l l1 l2 numbp slowp nostringp inputp timep grindp inchar largp)
@@ -667,27 +513,28 @@
        (do ((i numbp (1- i)) (l2)) ((zerop i) (setq l1 (nconc l1 l2)))
 	 (setq l2 (cons (car l) l2) l (cdr l)))
        loop (if (null l1) (return '$done))
-       ((lambda (errset incharp)
-	  (errset
-	   (cond ((and (not nostringp) incharp)
-		  (let ((linelable (car l1))) (mterpri) (printlabel))
-		  (if grindp
-		      (mgrind (meval1 (car l1)) nil)
-		      (mapc #'(lambda (x) (write-char x)) (mstring (meval1 (car l1)))))	;gcl doesn't like a
+       (let ((errset 'errbreak2)
+	     (incharp (char= (getlabcharn (car l1)) inchar)))
+	 (errset
+	  (cond ((and (not nostringp) incharp)
+		 (let ((*linelabel* (car l1))) (mterpri) (printlabel))
+		 (if grindp
+		     (mgrind (meval1 (car l1)) nil)
+		     (mapc #'(lambda (x) (write-char x)) (mstring (meval1 (car l1))))) ;gcl doesn't like a
 					; simple write-char, therefore wrapped it up in a lambda - are_muc
-		  (if (get (car l1) 'nodisp) (princ "$") (princ ";"))
-		  (mterpri))
-		 ((or incharp
-		      (prog2 (when (and timep (setq l (get (car l1) 'time)))
-			       (setq x (gctimep timep (cdr l)))
-			       (mtell-open "~A sec." (car l))
-			       (if x (mtell-open "  GCtime= ~A sec." (cdr l)))
-			       (mterpri))
-			  (not (or inputp (get (car l1) 'nodisp)))))
-		  (mterpri) (displa (list '(mlable) (car l1) (meval1 (car l1)))))
-		 (t (go a)))))
-	'errbreak2 (char= (getlabcharn (car l1)) inchar))
-       (if (and slowp (cdr l1) (not (continuep))) (return '$terminated))
+		 (if (get (car l1) 'nodisp) (princ "$") (princ ";"))
+		 (mterpri))
+		((or incharp
+		     (prog2 (when (and timep (setq l (get (car l1) 'time)))
+			      (setq x (gctimep timep (cdr l)))
+			      (mtell (intl:gettext "~A seconds") (car l))
+			      (if x (mtell (intl:gettext "  GC time = ~A seconds") (cdr l)))
+			      (mterpri))
+			 (not (or inputp (get (car l1) 'nodisp)))))
+		 (mterpri) (displa (list '(mlabel) (car l1) (meval1 (car l1)))))
+		(t (go a)))))
+       (when (and slowp (cdr l1) (not (continuep)))
+	 (return '$terminated))
        a    (setq l1 (cdr l1))
        (go loop))))
 
@@ -701,7 +548,7 @@
 
 (defmspec $alias (form)
   (if (oddp (length (setq form (cdr form))))
-      (merror "`alias' takes an even number of arguments."))
+      (merror (intl:gettext "alias: expected an even number of arguments.")))
   (do ((l nil (cons (alias (pop form) (pop form))
 		    l)))
       ((null form)
@@ -710,11 +557,13 @@
 (defmfun alias (x y)
   (cond ((nonsymchk x '$alias))
 	((nonsymchk y '$alias))
-	((not (eq (getcharn x 1) #\$))
-	 (merror "-ed symbols may not be aliased. ~M" x))
+        ((eq x y) y) ; x is already the alias of y
+; Not needed. We return the alias immediately if we already have one.
+;	((not (eq (getcharn x 1) #\$))
+;	 (merror "-ed symbols may not be aliased. ~M" x))
 	((get x 'reversealias)
 	 (if (not (eq x y))
-	     (merror "~M already is aliased." x)))
+	     (merror (intl:gettext "alias: ~M already has an alias.") x)))
 	(t (putprop x y'alias)
 	   (putprop y x 'reversealias)
 	   (add2lnc y $aliases)
@@ -734,7 +583,7 @@
 (defmfun stripdollar (x)
   (cond ((not (atom x))
 	 (cond ((and (eq (caar x) 'bigfloat) (not (minusp (cadr x)))) (implode (fpformat x)))
-	       (t (merror "Atomic arg required:~%~M" x))))
+	       (t (merror (intl:gettext "STRIPDOLLAR: argument must be an atom; found: ~M") x))))
 	((numberp x) x)
 	((null x) 'false)
 	((eq x t) 'true)
@@ -748,27 +597,16 @@
 (defmfun fullstrip1 (x)
   (or (and (numberp x) x)
       (let ((y (get x 'reversealias))) (if y (stripdollar y)))
-      (let ((u (rassoc x aliaslist :test #'eq)))
-	(if u (implode (string*1 (car u)))))
       (stripdollar x)))
 
 (defun string* (x)
   (or (and (numberp x) (exploden x))
-      (let ((u (rassoc x aliaslist :test #'eq)))
-	(if u (string*1 (car u))))
       (string*1 x)))
 
 (defun string*1 (x)
   (let ($stringdisp $lispdisp)
     (makestring x)))
 
-(defun makstring* (x)
-  (setq x (string* x))
-  (do ((l x (cdr l)))
-      ( (null l))
-    (rplaca l (ascii (car l))))
-  x)
-
 ;;; Note that this function had originally stripped a prefix of '|M|.  This
 ;;; was intended for operators such as 'MABS, but with the case flipping
 ;;; performed by explodec this test would always fail.  Dependent code has
@@ -777,7 +615,7 @@
 ;;;
 (defmfun $nounify (x)
   (if (not (or (symbolp x) (stringp x)))
-    (merror "nounify: argument must be a symbol or a string."))
+    (merror (intl:gettext "nounify: argument must be a symbol or a string; found: ~M") x))
   (setq x (amperchk x))
   (cond ((get x 'verb))
 	((get x 'noun) x)
@@ -792,9 +630,10 @@
 
 (defmfun $verbify (x)
   (if (not (or (symbolp x) (stringp x)))
-    (merror "verbify: argument must be a symbol or a string."))
+    (merror (intl:gettext "verbify: argument must be a symbol or a string; found: ~M") x))
   (setq x (amperchk x))
   (cond ((get x 'noun))
+        ((eq x '||) x)
 	((and (char= (char (symbol-name x) 0) #\%)
 	      (prog2
 		  ($nounify (implode (cons #\$ (cdr (exploden x)))))
@@ -823,18 +662,19 @@
 (mapc #'(lambda (x) (putprop (car x) (cadr x) 'alias)
 		(putprop (cadr x) (car x) 'reversealias))
       '(($block mprog block) ($lambda lambda lambda)
-	($abs mabs abs) ($subst $substitute subst)
+	($subst $substitute subst)
 	($go mgo go) ($signum %signum signum)
 	($return mreturn return) ($factorial mfactorial factorial)
 	($nouuo nouuo nouuo) ($rset *rset rset)
-	($ibase *read-base* *read-base*) ($obase *print-base* obase) ($nopoint *nopoint nopoint)
+        ($ibase *read-base* *read-base*) ($obase *print-base* obase)
+        ($nopoint *nopoint nopoint)
 	($modulus modulus modulus) ($zunderflow zunderflow zunderflow)
 	($ttyoff #.ttyoff ttyoff) ($writefile_on #.writefilep writefile_on)
 	($mode_declare $modedeclare mode_declare)))
 
 (mapc #'(lambda (x) (putprop (car x) (cadr x) 'alias))
       '(($ratcoeff $ratcoef) ($ratnum $ratnumer) ($true t)
-	($binom %binomial) ($derivative $diff) ($prod $product)
+        ($derivative $diff) ($prod $product)
 	($bothcoeff $bothcoef)))
 
 (defmfun amperchk (name)
@@ -893,7 +733,7 @@
 		     (setq maxima-error t)))
 	      (setq truename (truename savefile))
 	      (terpri savefile))
-	    (if maxima-error (let ((errset 'errbreak1)) (merror "Error in `stringout' attempt")))
+	    (if maxima-error (let ((errset 'errbreak1)) (merror (intl:gettext "stringout: unspecified error."))))
 	    (cl:namestring truename)))))
 
 (defmspec $labels (char)
@@ -908,7 +748,7 @@
      (if (> x 0) (setq x (- x)))
      (if (cdr $labels)
 	 (setq l (cddr $labels) outchar (getlabcharn $outchar)))
-     loop (if (null l) (merror "Improper call to %th"))
+     loop (if (null l) (merror (intl:gettext "%th: no such previous output: ~M") x))
      (if (and (char= (getlabcharn (car l)) outchar) (= (setq x (1+ x)) 0))
 					; Only the 1st alphabetic character of $OUTCHAR is tested.
 	 (return (meval (car l))))
@@ -953,18 +793,16 @@
       (errlfun1 mcatch))))
 
 (defmfun $throw (exp)
-  (if (null mcatch) (merror "`throw' not within `catch':~%~M" exp))
+  (if (null mcatch) (merror (intl:gettext "throw: not within 'catch'; expression: ~M") exp))
   (throw 'mcatch exp))
 
 (defmspec $time (l)
   (setq l (cdr l))
-  ;;(format t "~&Time:")
   (cons '(mlist simp)
 	(mapcar
 	 #'(lambda (x)
 	     (or (and (symbolp x)
-		      (setq x (or (get x 'time)
-				  (and (eq x '$%) (cons (cadr $lasttime) (caddr $lasttime)))))
+		      (setq x (get x 'time))
 		      (if (= (cdr x) 0)
 			  (car x)
 			  (list '(mlist simp) (car x) (cdr x))))
@@ -990,66 +828,46 @@
   #+excl "don't know quit function"
   #+lispworks (lispworks:quit))
 
-(defmfun $logout () (bye))
-
 ;; File-processing stuff.
 
-(defun mfile nil
-  (fullstrip (list $filename (setq $filenum (1+ $filenum)) $device $direc)))
-
-;; This prevents single blank lines from appearing at the top of video
-;; terminals.  If at the upper left corner and we want to print a blank
-;; line, leave the cursor there and send the blank line to transcript
-;; files only.
-
 (defmfun mterpri ()
-  (if smart-tty
-      (let ((#.ttyoff t))
-	(terpri))
-      (terpri)))
-
-(defmfun $pagepause (x)
-  (pagepause1 nil x))
-
-(defun pagepause1 (xx yy)
-  (declare (ignore xx yy))
-  (merror "`pagepause' does not exist in this system."))
+   (terpri))
 
 (defmspec $status (form)
   (setq form (cdr form))
   (let* ((keyword (car form))
-	 (feature (cadr form)))
-    (assert (symbolp keyword))
-    (assert (or (stringp feature) (symbolp feature)))
+         (feature (cadr form)))
+    (when (not (symbolp keyword))
+      (merror (intl:gettext "status: first argument must be a symbol; found: ~M") keyword))
+    (when (not (or (stringp feature) (symbolp feature)))
+      (merror
+        (intl:gettext "status: second argument must be symbol or a string; found: ~M") feature))
     (case keyword
       ($feature (cond ((null feature) (dollarify *features*))
-		      ((member (intern
-                         (if (stringp feature)
-                           (maybe-invert-string-case feature)
-                           (symbol-name (fullstrip1 feature)))
-                         'keyword)
-			     *features* :test #'equal) t)))
-      ($status '((mlist simp) $feature $status))
-      (t (merror "Unknown argument - `status':~%~M" keyword)))))
+                      ((member (intern (if (stringp feature)
+                                           (maybe-invert-string-case feature)
+                                           (symbol-name (fullstrip1 feature)))
+                                       'keyword)
+                               *features* :test #'equal) t)))
+      (t (merror (intl:gettext "status: unknown argument: ~M") keyword)))))
 
-(defquote $sstatus (status-function item)
-  (cond ((equal status-function '$feature)
-	 (pushnew ($mkey item) *features*) t)
-	((equal status-function '$nofeature)
-	 (setq *features* (delete ($mkey item) *features*)) t)
-	(t (error "know only how to set and remove feature status"))))
+(defquote $sstatus (keyword item)
+  (cond ((equal keyword '$feature)
+         (pushnew ($mkey item) *features*) t)
+        ((equal keyword '$nofeature)
+         (setq *features* (delete ($mkey item) *features*)) t)
+        (t
+         (merror (intl:gettext "sstatus: unknown argument: ~M") keyword))))
 
-(do ((l '($sqrt $erf $sin $cos $tan $log $plog $sec $csc $cot $sinh $cosh
-	  $tanh $sech $csch $coth $asin $acos $atan $acot $acsc $asec $asinh
-	  $acosh $atanh $acsch $asech $acoth $binomial $gamma $genfact $del)
-	(cdr l)))
-    ((null l))
-  ((lambda (x)
-     (putprop (car l) x 'alias)
-     (putprop x (car l) 'reversealias))
-   ($nounify (car l))))
+(dolist (l '($sin $cos $tan $log $plog $sec $csc $cot $sinh $cosh
+	     $tanh $sech $csch $coth $asin $acos $atan $acot $acsc $asec $asinh
+	     $acosh $atanh $acsch $asech $acoth $binomial $gamma $genfact $del))
+  (let ((x ($nounify l)))
+    (putprop l x 'alias)
+    (putprop x l 'reversealias)))
 
 ($nounify '$sum)
+($nounify '$lsum)
 ($nounify '$product)
 ($nounify '$integrate)
 ($nounify '$limit)
@@ -1059,7 +877,6 @@
 
 (mapc #'(lambda (x) (putprop (car x) (cadr x) 'assign))
       '(($debugmode debugmode1)
-	($pagepause pagepause1)
 	($ttyintfun ttyintfunsetup)
 	($fpprec fpprec1) ($poislim poislim1)
 	($default_let_rule_package let-rule-setter)
