@@ -12,8 +12,6 @@
 
 (macsyma-module transs)
 
-(transl-module transs)
-
 (defmvar *transl-file-debug* nil
   "set this to T if you don't want to have the temporary files
 	used automaticaly deleted in case of errors.")
@@ -32,9 +30,6 @@
   "It TRUE messages about translation of the file are sent
 	 to the TTY also.")
 
-(defmvar $tr_windy t
-  "Generate helpful comments and programming hints.")
-
 (defvar *translation-msgs-files* nil
   "Where the warning and other comments goes.")
 
@@ -61,36 +56,28 @@
       $tr_numer
       $define_variable))
 
-(defmacro trlisp-inputname-d1 () ;; so hacks on DEFAULTF will not
-  '`,(pathname "")) ;; stray the target.
-
-(defmacro trlisp-outputname-d1 ()
-  '`,(pathname (maybe-invert-string-case (symbol-name (stripdollar $tr_output_file_default)))))
-
-(defmacro trlisp-outputname ()
-  '`,(make-pathname :type "LISP"))
-
-(defmacro trlisp-outputname-temp ()
-  '`,(pathname "_trli_"))
-
-(defmacro trtags-outputname ()
-  '`,(pathname "tags"))
-
-(defmacro trtags-outputname-temp ()
-  '`,(pathname "_tags_"))
-
-(defmacro trcomments-outputname ()
-  '`,(pathname "unlisp"))
-
-(defmacro trcomments-outputname-temp ()
-  '`,(pathname "_unli_"))
-
 (defvar declares nil)
 
+(defmacro with-maxima-io-syntax (&rest forms)
+  `(let ((*readtable* (copy-readtable nil))
+        (*print-circle* nil) (*print-level* nil) (*print-length* nil) (*print-base* 10.) (*print-radix* t)
+	#-gcl (*print-pprint-dispatch* (copy-pprint-dispatch)))
+    #-gcl
+    (progn
+      #-(or scl allegro)
+      (setf (readtable-case *readtable*) :invert)
+      #+(or scl allegro)
+      (unless #+scl (eq ext:*case-mode* :lower)
+	      #+allegro (eq excl:*current-case-mode* :case-sensitive-lower)
+	(setf (readtable-case *readtable*) :invert))
+      (set-pprint-dispatch '(cons (member maxima::defmtrfun))
+			   #'pprint-defmtrfun))
+    ,@forms))
+
 (defmspec $compfile (forms)
     (setq forms (cdr forms))
     (if (eq 1 (length forms))
-      (merror "compfile: bravely refusing to write file of length 0"))
+      (merror (intl:gettext "compfile: no functions specified; I refuse to create an empty file.")))
     (bind-transl-state
      (setq $transcompile t
 	   *in-compfile* t)
@@ -100,7 +87,7 @@
         (*translation-msgs-files* nil))
        (pop forms)
        (unwind-protect
-	    (progn
+	    (with-maxima-io-syntax
 	      (setq transl-file (open out-file-name :direction :output :if-exists :overwrite :if-does-not-exist :create :element-type 'character))
 	      (cond ((or (member '$all forms :test #'eq)
 			 (member '$functions forms :test #'eq))
@@ -122,27 +109,19 @@
 			      (setq t-error (print-abort-msg item 'compfile)))
 			     (t
 			      (when $compgrind
-				(mformat transl-file "~2%;; Function ~:@M~%" item))
+				(mformat transl-file (intl:gettext "~2%;; Function ~:@M~%") item))
 			      (print* t-item))))))
-          (to-macsyma-namestring out-file-name))
+          (pathname out-file-name))
 	 ;; unwind-protected
 	 (if transl-file (close transl-file))
 	 (if t-error (delete-file transl-file))))))
 
 (defun compile-function (f)
-  (mformat  *translation-msgs-files* "~%Translating ~:@M" f)
+  (mformat  *translation-msgs-files* (intl:gettext "~%Translating ~:@M") f)
   (let ((fun (tr-mfun f)))
     (cond (tr-abort  nil)
 	  (t fun))))
 
-(defvar tr-defaultf nil
-  "A default only for the case of no arguments to $translate_file")
-
-;;; Temporary hack during debugging of this  code.
-
-(defun mergef (x y)
-  (merge-pathnames y x))
-
 (defun $compile_file (input-file &optional bin-file translation-output-file &aux result)
   (setq input-file (maxima-string input-file))
   (and bin-file(setq  bin-file (maxima-string bin-file)))
@@ -202,18 +181,7 @@
   (cleanup)
   ;; we want the thing to start with a newline..
   (newline in-stream)
-  (let ((*readtable* (copy-readtable nil))
-	#-gcl (*print-pprint-dispatch* (copy-pprint-dispatch)))
-    #-gcl
-    (progn
-      #-(or scl allegro)
-      (setf (readtable-case *readtable*) :invert)
-      #+(or scl allegro)
-      (unless #+scl (eq ext:*case-mode* :lower)
-	      #+allegro (eq excl:*current-case-mode* :case-sensitive-lower)
-	(setf (readtable-case *readtable*) :invert))
-      (set-pprint-dispatch '(cons (member maxima::defmtrfun))
-			   #'pprint-defmtrfun))
+  (with-maxima-io-syntax
     (loop while (and (setq expr (mread in-stream)) (consp expr))
 	  do (setq transl (translate-macexpr-toplevel (third expr)))
 	     (cond
@@ -223,29 +191,8 @@
 		(format out-stream "~a" transl))))))
 
 
-(defun translate-from-stream (from-stream &key to-stream eval pretty (print-function #'prin1)
-			      &aux expr transl)
-  (bind-transl-state
-   (loop
-      with *in-translate-file* = t
-      with *print-pretty* = pretty
-      while (and (setq expr (mread from-stream)) (consp expr))
-      do (setq transl (translate-macexpr-toplevel (third expr)))
-      (cond (eval (eval transl)))
-      (cond (to-stream (funcall print-function transl to-stream)))
-      (loop for v in forms-to-compile-queue
-	 do (show v to-stream)
-	 when to-stream
-	 do (funcall print-function v to-stream)
-	 when eval
-	 do (eval v))
-      (setq forms-to-compile-queue nil))))
-
 (defvar trf-start-hook nil)
 
-(defun delete-old-and-open (x)
-  (open x :direction :output))
-
 (defun alter-pathname (pathname &rest options)
   (apply 'make-pathname :defaults (pathname  pathname) options))
 
@@ -286,18 +233,18 @@ translated."
 	   *untranslated-functions-called*))
     (when hint
       (format  stream
-	       "~2%/* The compiler might be able to optimize some function calls
-   if you prepend the following declaration to your maxima code: */~%")
+	       (intl:gettext "~2%/* The compiler might be able to optimize some function calls
+   if you prepend the following declaration to your Maxima code: */~%"))
       (mgrind `(($eval_when) $translate (($declare_translated) ,@hint))
 	      stream)
       (format stream "$"))
     (when *untranslated-functions-called*
-      (format stream "~2%/* The following functions are not known to be translated.~%")
+      (format stream (intl:gettext "~2%/* The following functions are not known to be translated:~%"))
       (mgrind `((mlist) ,@(nreverse *untranslated-functions-called*)) stream)
       (format stream "$ */"))
     (fresh-line stream)
     (when (or hint *untranslated-functions-called*)
-      (format t "~&See the `unlisp' file for possible optimizations.~%"))))
+      (format t (intl:gettext "~&translator: see the 'unlisp' file for possible optimizations.~%")))))
 
 (defun translate-file (in-file-name out-file-name &optional (ttymsgsp $tr_file_tty_messagesp)
 		       &aux warn-file translated-file *translation-msgs-files*
@@ -327,19 +274,19 @@ translated."
 	   (multiple-value-bind (secs mins hours day month year dow dst tz)
 	       (decode-universal-time (get-universal-time))
 	     (declare (ignore dow))
-	     (format out-stream ";;; Translated on: ~D-~2,'0D-~2,'0D ~2,'0D:~2,'0D:~2,'0D~A~%"
+	     (format out-stream (intl:gettext ";;; Translated on: ~D-~2,'0D-~2,'0D ~2,'0D:~2,'0D:~2,'0D~A~%")
 		     year month day hours mins secs (timezone-iso8601-name dst tz))))
-	 (format out-stream ";;; Maxima System version: ~A~%" *autoconf-version*)
-	 (format out-stream ";;; Lisp type:    ~A~%" (lisp-implementation-type))
-	 (format out-stream ";;; Lisp version: ~A~%" (lisp-implementation-version))
-	 (format out-stream "~%(in-package :maxima)")
-	 (format warn-stream "~%This is the unlisp file for ~A "
+	 (format out-stream (intl:gettext ";;; Maxima version: ~A~%") *autoconf-version*)
+	 (format out-stream (intl:gettext ";;; Lisp implementation: ~A~%") (lisp-implementation-type))
+	 (format out-stream (intl:gettext ";;; Lisp version: ~A~%") (lisp-implementation-version))
+	 (format out-stream "(in-package :maxima)~%")
+	 (format warn-stream (intl:gettext "This is the unlisp file for ~A~%")
 		 (namestring (pathname in-stream)))
 	 (mformat out-stream
-		  "~%;;** Variable settings were **~%~%")
+		  (intl:gettext ";;** Translator flags were: **~%~%"))
 	 (loop for v in (cdr $tr_state_vars)
 		do (mformat out-stream   ";; ~:M: ~:M;~%" v (symbol-value v)))
-	 (mformat *terminal-io* "~%Translation begun on ~A.~%"
+	 (mformat *terminal-io* (intl:gettext "translator: begin translating ~A.~%")
 		  (pathname in-stream))
 	 (call-batch1 in-stream out-stream)
 	 (insert-necessary-function-declares warn-stream)
@@ -392,60 +339,16 @@ translated."
   (terpri*)
   (princ* ";;;"))
 
-(defun print-transl-modules ()
-  (new-comment-line)
-  (print-module 'transl-autoload)
-  (do ((j 0 (1+ j))
-       (s (delete 'transl-autoload (copy-list transl-modules) :test #'equal)
-	  (cdr s)))
-      ((null s))
-    (if (= 0 (rem j 3)) (new-comment-line))
-    (print-module (car s))))
-
-
-(defun print-transl-header (source)
-  (mformat transl-file ";;; -*- Mode: Lisp; package:maxima; syntax:common-lisp -*-~%")
-  (if source
-      (mformat transl-file ";;; Translated code for ~A" source)
-      (mformat transl-file ";;; Translated Maxima functions generated by `compfile'."))
-  (mformat transl-file "~%;;; Written on ~:M, from Maxima ~A~%;;;~%" ($timedate) $version)
-  (print-transl-modules)
-  (mformat transl-file
-	   "~%~
-	   ~%~
-	   ~%(eval-when (:compile-toplevel :execute) ~
-	   ~%      (setq *infile-name-key*~
-	   ~%               ((lambda (file-name)~
-	   ~%                           ;; temp crock for multics.~
-	   ~%                          (cond ((eq (ml-typep file-name) 'list)~
-	   ~%                                 (namestring file-name))~
-	   ~%                                (t file-name)))~
-	   ~%                  (truename infile))))~
-	   ~%~
-	   ~%(eval-when (:compile-toplevel) ~
-	   ~%   (setq $tr_semicompile '~S)~
-	   ~%   (setq forms-to-compile-queue ()))~
-	   ~%~%;;; ~S~%~%"
-	   $tr_semicompile source)
-  (cond ($transcompile
-	 (update-global-declares)
-	 (when $compgrind
-	   (mformat transl-file ";;; General declarations required for translated Maxima code.~%"))
-	 (print* `(declare . ,declares)))))
-
 (defun print-abort-msg (fun from)
   (mformat *translation-msgs-files*
-	   "~:@M failed to Translate.~
-	    ~%~A will continue, but file output will be aborted."
+	   (intl:gettext "compfile: failed to translate ~:@M.~
+	    ~A will continue, but file output will be aborted.~%") ;; WTF DOES THIS MEAN ???
 	   fun from))
 
-(defmacro extension-filename (x)
-  `(caddr (namelist ,x)))
-
 (defmspec $translate (functs)
   (setq functs (cdr functs))
-  (cond ((and functs ($listp (car functs)))
-	 (merror "Use the function `translate_file'"))
+  (cond ((and functs (stringp (car functs)))
+	 (merror (intl:gettext "translate: call 'translate_file' to translate a file; found: ~M") (car functs)))
 	(t
 	 (cond ((or (member '$functions functs :test #'eq)
 		    (member '$all functs :test #'eq))
@@ -457,9 +360,7 @@ translated."
 		  (let ((it (translate-function ($verbify (car l)))))
 		    (if it (push it v))))
 		 (t
-		  (tr-tell
-		   (car l)
-		   " is an illegal argument to `translate'.")))))))
+		  (tr-format (intl:gettext "error: 'translate' argument must be an atom; found: ~:M~%") (car l))))))))
 
 
 (declare-top (special forms-to-compile-queue))
