@@ -21,7 +21,7 @@
         "rtest3" "rtest8"
         ((mlist simp) "rtest12" 76 78)
         "rexamples"
-        ((mlist simp) "rtesthyp" 103 104 105 112 113 123 124 128)
+        ((mlist simp) "rtesthyp" 105 112 113 123 124 128)
         ((mlist simp) "rtest_hypgeo" 143)
         "rtestmt19937"
         "rtest_allnummod"
@@ -33,10 +33,11 @@
         "rtest_scalarp"
         "rtest_everysome"
         "rtestint"
+        "rtest_numth"
         "rtestifactor"
         ((mlist simp) "rtest_equal" 157 160)
         "rtest_abs"
-        ((mlist simp) "rtest_taylor" 88 91 94 96 99 118 119 120 121 123 124)
+        ((mlist simp) "rtest_taylor" 88 91 94 99 118 119 120 121 123 124)
         ((mlist simp) "rtest_dot")
         "rtest_mset"
         "rtest_boolean"
@@ -44,7 +45,7 @@
         ((mlist simp) "rtest_map" 2 3 4)
         ((mlist simp) "rtest_sign" 21 25 30 40 65 72 77 79)
         "rtest_algebraic"
-        ((mlist simp) "rtest_gamma" 473 474)
+        "rtest_gamma"
         "rtest_expintegral"
         "rtest_signum"
         "rtest_lambert_w"
@@ -54,6 +55,8 @@
         "rtest_ask"
         ((mlist simp) "rtest_sqrt" 89)
         ((mlist simp) "rtest_carg" 40 41)
-        ((mlist simp) "rtest_log" 11)
+        ((mlist simp) "rtest_log")
         ((mlist simp) "rtest_power" 19 20 26 58 62 65)
+        "rtestdefstruct"
+        ((mlist) "rtest_laplace" 29 49 50 51 54 59 60 61 62 78 80)
 	))
